#!/usr/bin/env node

/**
 * @file Build this project.
 */

process.chdir(__dirname + '/..');

"use strict";

var uiContrib = require('apeman-tmpl-contrib-official/lib/ui_contrib'),
    tasking = require('apeman-dev-commons-tasking'),
    path = require('path'),
    coz = require('coz'),
    glob = require('glob'),
    async = require('async');

var pkg = require('../package.json');

var apDependencies = [];

tasking.runTasks([
    function renderProject(callback) {
        uiContrib.render({
            pkg: pkg,
            ignore: [],
            year: new Date().getFullYear(),
            get signature() {
                try {
                    return require('../.signature');
                } catch (e) {
                    return null;
                }
            },
            dependencies: {
                'angular': '~1.4.3'
            },
            get docs() {
                var docs = {};
                glob.sync('assets/docs/**/*.md').filter(function (filename) {
                    return path.basename(filename) !== 'index.md';
                }).forEach(function (filename) {
                    docs[path.basename(filename, '.md')] = filename;
                });
                return docs;
            }
        }, callback);
    },
    function renderAssets(callback) {
        coz.render([
            'assets/**/.*.bud'
        ], callback);
    },
    function buildDependencies(callback) {
        async.eachSeries(apDependencies, function (name, callback) {
            var dist = require(name);
            async.eachSeries([
                'assets/test/dependencies',
                'docs/demo/resources'
            ], function (dest, callback) {
                dist()(dest, callback);
            }, callback);
        }, callback);
    },
    function generateThis(callback) {
        var dist = require('../dist');
        async.eachSeries([
            'assets/dist',
            'docs/demo/resources'
        ], function (dest, callback) {
            dist()(dest, callback);
        }, callback);
    }
], true);