(function (ng) {
    /**
     * @ngdoc module
     * @module apeman-ui-contrib-angular-arraying
     * @name apeman-ui-contrib-angular-arraying
     * @description
     * apeman ui module for angular to work with array.
     */

    "use strict";

    ng
        .module('apeman-ui-contrib-angular-arraying', [
        ]);
})(angular);(function (ng) {
    /**
     * @ngdoc service
     * @module apeman-ui-contrib-angular-arraying
     * @name apArray
     * @description
     * Convenience functions for array.
     */

    "use strict";

    ng
        .module('apeman-ui-contrib-angular-arraying')
        .service('apArray', function () {
            var s = this;

            /**
             * @ngdoc method
             * @name apArray#contains
             * @description Detect contain an entry or not.
             * @param {Array} array - Array to work with.
             * @param {*} entry - Entry to test.
             * @returns {boolean} - Contains or not.
             */
            s.contains = function (array, entry) {
                return !!(array && ~array.indexOf(entry));
            };

            /**
             * @ngdoc method
             * @name apArray#mapPropertyValue
             * @description Map property values.
             * @param {Array} array - Array to work with.
             * @param {string} key - Key to extract.
             * @returns {Array} - Mapped property values.
             */
            s.mapPropertyValue = function (array, key) {
                return array && array.map(function (entry) {
                        return entry[key];
                    });
            };
            /**
             * @ngdoc method
             * @name apArray#rejectByPropertyValue
             * @description Reject array entry by property value.
             * @param {Array} array - Array to work with.
             * @param {string} key - Key of property.
             * @param {*} val - Property value to reject.
             * @returns {Array} - Filtered array.
             */
            s.rejectByPropertyValue = function (array, key, val) {
                return array && array.filter(function (entry) {
                        return entry[key] !== val;
                    });
            };

            /**
             * @ngdoc method
             * @name apArray#unique
             * @description Create unique array.
             * @param {Array} array - Array to be unique.
             * @returns {Array} - Unique array.
             */
            s.unique = function (array) {
                if (!array) {
                    return array;
                }
                var known = {},
                    result = [];
                for (var i = 0, len = array && array.length; i < len; i++) {
                    var value = array[i];
                    if (known[value]) {
                        continue;
                    }
                    result.push(value);
                    known[value] = true;
                }
                return result;
            };

        });
})(angular);